@@ -31,7 +31,7 @@ from dxpy.bindings import *
 # DXApplet #
 ############
 
-def makeNonexistentAPIWrapper(method):
+def _makeNonexistentAPIWrapper(method):
     def nonexistentAPIWrapper(object_id, input_params=None, always_retry=None, **kwargs):
         raise DXError("Wrapper for " + method + " does not exist")
     return nonexistentAPIWrapper
@@ -46,16 +46,16 @@ class DXApplet(DXDataObject):
     _class = "applet"
 
     _describe = staticmethod(dxpy.api.applet_describe)
-    _add_types = staticmethod(makeNonexistentAPIWrapper("/applet-xxxx/addTypes"))
-    _remove_types = staticmethod(makeNonexistentAPIWrapper("/applet-xxxx/removeTypes"))
+    _add_types = staticmethod(_makeNonexistentAPIWrapper("/applet-xxxx/addTypes"))
+    _remove_types = staticmethod(_makeNonexistentAPIWrapper("/applet-xxxx/removeTypes"))
     _get_details = staticmethod(dxpy.api.applet_get_details)
-    _set_details = staticmethod(makeNonexistentAPIWrapper("/applet-xxxx/setDetails"))
-    _set_visibility = staticmethod(makeNonexistentAPIWrapper("/applet-xxxx/setVisibility"))
+    _set_details = staticmethod(_makeNonexistentAPIWrapper("/applet-xxxx/setDetails"))
+    _set_visibility = staticmethod(_makeNonexistentAPIWrapper("/applet-xxxx/setVisibility"))
     _rename = staticmethod(dxpy.api.applet_rename)
     _set_properties = staticmethod(dxpy.api.applet_set_properties)
     _add_tags = staticmethod(dxpy.api.applet_add_tags)
     _remove_tags = staticmethod(dxpy.api.applet_remove_tags)
-    _close = staticmethod(makeNonexistentAPIWrapper("/applet-xxxx/close"))
+    _close = staticmethod(_makeNonexistentAPIWrapper("/applet-xxxx/close"))
     _list_projects = staticmethod(dxpy.api.applet_list_projects)
 
     def _new(self, dx_hash, **kwargs):
@@ -81,12 +81,12 @@ class DXApplet(DXDataObject):
 
         .. note:: It is highly recommended that the higher-level module
            :mod:`dxpy.app_builder` or (preferably) its frontend
-           `dx-build-applet <http://wiki.dnanexus.com/DxBuildApplet>`_ be used
+           `dx-build-applet <https://wiki.dnanexus.com/DxBuildApplet>`_ be used
            instead for applet creation.
 
         Creates an applet with the given parameters. See the API
         documentation for the `/applet/new
-        <http://wiki.dnanexus.com/API-Specification-v1.0.0/Applets#API-method%3A-%2Fapplet%2Fnew>`_
+        <https://wiki.dnanexus.com/API-Specification-v1.0.0/Applets#API-method%3A-%2Fapplet%2Fnew>`_
         method for more info. The applet is not run until :meth:`run()`
         is called.
 
@@ -112,7 +112,7 @@ class DXApplet(DXDataObject):
         Returns the contents of the applet. The result includes the
         key-value pairs as specified in the API documentation for the
         `/applet-xxxx/get
-        <http://wiki.dnanexus.com/API-Specification-v1.0.0/Applets#API-method%3A-%2Fapplet-xxxx%2Fget>`_
+        <https://wiki.dnanexus.com/API-Specification-v1.0.0/Applets#API-method%3A-%2Fapplet-xxxx%2Fget>`_
         method.
         """
         return dxpy.api.applet_get(self._dxid, **kwargs)
