@@ -32,6 +32,7 @@ import dxpy, dxpy.app_builder
 from dxpy import logger
 
 from dxpy.utils.resolver import resolve_path, is_container_id
+from dxpy.app_categories import APP_CATEGORIES
 
 parser = argparse.ArgumentParser(description="Uploads a DNAnexus App.")
 
@@ -41,7 +42,8 @@ APP_VERSION_RE = re.compile("^([1-9][0-9]*|0)\.([1-9][0-9]*|0)\.([1-9][0-9]*|0)(
 parser.add_argument("src_dir", help="App or applet source directory (default: current directory)", nargs='?')
 
 parser.set_defaults(mode="app")
-parser.add_argument("--create-app", help=argparse.SUPPRESS, action="store_const", dest="mode", const="app")
+parser.add_argument("--create-app", help="Create an app (otherwise, creates an applet)", action="store_const",
+                    dest="mode", const="app")
 parser.add_argument("--create-applet", help=argparse.SUPPRESS, action="store_const", dest="mode", const="applet")
 parser.add_argument("-d", "--destination", help="Specifies the destination project, destination folder, and/or name for the applet, in the form [PROJECT_NAME_OR_ID:][/[FOLDER/][NAME]]. Overrides the project, folder, and name fields of the dxapp.json, if they were supplied.", default='.')
 
@@ -50,11 +52,13 @@ parser.add_argument("--no-temp-build-project", help="When building an app, build
 
 parser.set_defaults(parallel_build=True)
 parser.add_argument("--parallel-build", help=argparse.SUPPRESS, action="store_true", dest="parallel_build")
-parser.add_argument("--no-parallel-build", help="Build with make instead of make -jN.", action="store_false", dest="parallel_build")
+parser.add_argument("--no-parallel-build", help="Build with make instead of make -jN.", action="store_false",
+                    dest="parallel_build")
 
 # --[no-]publish
 parser.set_defaults(publish=False)
-parser.add_argument("--publish", help="Publish the resulting app and make it the default.", action="store_true", dest="publish")
+parser.add_argument("--publish", help="Publish the resulting app and make it the default.", action="store_true",
+                    dest="publish")
 parser.add_argument("--no-publish", help=argparse.SUPPRESS, action="store_false", dest="publish")
 
 # --[no-]remote
@@ -62,9 +66,14 @@ parser.set_defaults(remote=False)
 parser.add_argument("--remote", help="Build the app remotely.", action="store_true", dest="remote")
 parser.add_argument("--no-remote", help=argparse.SUPPRESS, action="store_false", dest="remote")
 
-parser.add_argument("-f", "--overwrite", help="Remove existing applet(s) of the same name in the destination folder.", action="store_true", default=False)
-parser.add_argument("-v", "--version", help="Override the version number supplied in the manifest.", default=None, dest="version_override", metavar='VERSION')
-parser.add_argument("-b", "--bill-to", help="Entity (of the form user-NAME or org-ORGNAME) to bill for the app.", default=None, dest="bill_to", metavar='USER_OR_ORG')
+parser.add_argument("-f", "--overwrite", help="Remove existing applet(s) of the same name in the destination folder.",
+                    action="store_true", default=False)
+parser.add_argument("-a", "--archive", help="Archive existing applet(s) of the same name in the destination folder.",
+                    action="store_true", default=False)
+parser.add_argument("-v", "--version", help="Override the version number supplied in the manifest.", default=None,
+                    dest="version_override", metavar='VERSION')
+parser.add_argument("-b", "--bill-to", help="Entity (of the form user-NAME or org-ORGNAME) to bill for the app.",
+                    default=None, dest="bill_to", metavar='USER_OR_ORG')
 
 # --[no-]version-autonumbering
 parser.set_defaults(version_autonumbering=True)
@@ -220,7 +229,7 @@ def _lint(dxapp_json_filename):
 
     if 'categories' in app_spec:
         for category in app_spec['categories']:
-            if category not in ['Import', 'Export', 'Alignment', 'Variation calling', 'Annotation', 'Reports', 'RNA-Seq', 'Statistics', 'Debugging', 'Assembly']:
+            if category not in APP_CATEGORIES:
                 logger.warn('app has unrecognized category "%s"' % (category,))
             if category == 'Import':
                 if not app_spec['title'].endswith('Importer'):
@@ -523,10 +532,14 @@ def _build_app_remote(mode, src_dir, publish=False, destination_override=None,
     return
 
 
-def build_and_upload_locally(src_dir, mode, overwrite=False, publish=False, destination_override=None, version_override=None, bill_to_override=None, use_temp_build_project=True, do_parallel_build=True, do_version_autonumbering=True, do_try_update=True, dx_toolkit_autodep="stable", do_build_step=True, do_upload_step=True, do_check_syntax=True, dry_run=False, return_object_dump=False):
+def build_and_upload_locally(src_dir, mode, overwrite=False, archive=False, publish=False, destination_override=None,
+                             version_override=None, bill_to_override=None, use_temp_build_project=True,
+                             do_parallel_build=True, do_version_autonumbering=True, do_try_update=True,
+                             dx_toolkit_autodep="stable", do_build_step=True, do_upload_step=True, do_check_syntax=True,
+                             dry_run=False, return_object_dump=False):
+    _verify_app_source_dir(src_dir, enforce=do_check_syntax)
 
     app_json = _parse_app_spec(src_dir)
-    _verify_app_source_dir(src_dir, enforce=do_check_syntax)
 
     working_project = None
     using_temp_project = False
@@ -567,6 +580,7 @@ def build_and_upload_locally(src_dir, mode, overwrite=False, publish=False, dest
                 bundled_resources,
                 check_name_collisions=(mode == "applet"),
                 overwrite=overwrite and mode == "applet",
+                archive=archive and mode == "applet",
                 project=working_project,
                 override_folder=override_folder,
                 override_name=override_applet_name,
@@ -658,6 +672,9 @@ def main(**kwargs):
     if args.dx_toolkit_autodep in ['beta', 'unstable']:
         logging.warn('The --dx-toolkit-beta-autodep and --dx-toolkit-unstable-autodep flags have no effect and will be removed at some date in the future.')
 
+    if args.overwrite and args.archive:
+        parser.error("Options -f/--overwrite and -a/--archive cannot be specified together")
+
     if not args.remote:
         # LOCAL BUILD
 
@@ -666,6 +683,7 @@ def main(**kwargs):
                 args.src_dir,
                 args.mode,
                 overwrite=args.overwrite,
+                archive=args.archive,
                 publish=args.publish,
                 destination_override=args.destination,
                 version_override=args.version_override,
