@@ -42,7 +42,7 @@ parser.add_argument('--properties', help='A set of properties (key/value pairs)
 parser.add_argument('--discard_names', action="store_true", help='If selected, the read names (that appear in the FASTA/FASTQ file) will not be carried forward into the Reads table object. If read names are not important to you, this option will save some storage space.')
 parser.add_argument('--discard_qualities', action="store_true", help='If selected, the quality values (that appear in the FASTQ file) will not be carried forward into the Reads table object.')
 parser.add_argument('--qual_encoding', default='auto', help='FASTQ files may contain quality values using one of two different encodings, where a quality value of 0 is represented by the ASCII character 33 or 64. Set this option to "phred33" or "phred64" if you know which encoding your files are using, or leave this to "auto" if you want the encoding to be detected automatically in a heuristic way.')
-parser.add_argument('--pair_orientation', help="For paired reads: The expected relative orientation of the two mates, if known. One of 'FR', 'FF', 'RF', or 'RR' ('F' stands for forward strand, 'R' stands for reverse strand; see http://wiki.dnanexus.com/Types/Reads for more).")
+parser.add_argument('--pair_orientation', help="For paired reads: The expected relative orientation of the two mates, if known. One of 'FR', 'FF', 'RF', or 'RR' ('F' stands for forward strand, 'R' stands for reverse strand; see https://wiki.dnanexus.com/Types/Reads for more).")
 parser.add_argument('--pair_min_dist', help='For paired reads: Smallest expected fragment length (in bp), if known.')
 parser.add_argument('--pair_max_dist', help='For paired reads: Largest expected fragment length (in bp), if known.')
 parser.add_argument('--pair_avg_dist', help='For paired reads: Average fragment length (in bp), if known.')
