@@ -42,6 +42,10 @@ def run_dx_app_wizard():
         wizard.sendline()
         wizard.expect("Version")
         wizard.sendline()
+        wizard.expect("Choose a category")
+        wizard.sendline("Assembly")
+        wizard.expect("Choose a category")
+        wizard.sendline()
         wizard.expect("1st input name")
         wizard.sendline("in1")
         wizard.expect("Label")
